aboutsummaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
authorPieter Wuille <pieter@wuille.net>2024-07-30 16:21:51 -0400
committerPieter Wuille <pieter@wuille.net>2024-08-01 14:07:54 -0400
commit0e52728a2d6ccafcfecfefbb5a0432a9881d8e0d (patch)
tree7e5db7de4ba1d6232df2cf764a051c81bd4af13d /src
parent9774a958b501a6d439a734e18b29e04f59f973f6 (diff)
clusterlin: rename Intersect -> IntersectPrefixes
This makes it clearer what the function does.
Diffstat (limited to 'src')
-rw-r--r--src/cluster_linearize.h8
-rw-r--r--src/test/fuzz/cluster_linearize.cpp6
2 files changed, 7 insertions, 7 deletions
diff --git a/src/cluster_linearize.h b/src/cluster_linearize.h
index 07d28a9aa5..61b76968cf 100644
--- a/src/cluster_linearize.h
+++ b/src/cluster_linearize.h
@@ -333,12 +333,12 @@ public:
* of the linearization that has a feerate not below subset's.
*
* This is a crucial operation in guaranteeing improvements to linearizations. If subset has
* a feerate not below GetChunk(0)'s, then moving Intersect(subset) to the front of (what
* remains of) the linearization is guaranteed not to make it worse at any point.
*
* See https://delvingbitcoin.org/t/introduction-to-cluster-linearization/1032 for background.
*/
- SetInfo<SetType> Intersect(const SetInfo<SetType>& subset) const noexcept
+ SetInfo<SetType> IntersectPrefixes(const SetInfo<SetType>& subset) const noexcept
{
Assume(subset.transactions.IsSubsetOf(m_todo));
SetInfo<SetType> accumulator;
@@ -719,7 +719,7 @@ std::pair<std::vector<ClusterIndex>, bool> Linearize(const DepGraph<SetType>& de
// sure we don't pick something that makes us unable to reach further diagram points
// of the old linearization.
if (old_chunking.NumChunksLeft() > 0) {
- best = old_chunking.Intersect(best);
+ best = old_chunking.IntersectPrefixes(best);
}
}
@@ -333,12 +333,12 @@ public:
*
* This is a crucial operation in guaranteeing improvements to linearizations. If subset has
- * a feerate not below GetChunk(0)'s, then moving Intersect(subset) to the front of (what
- * remains of) the linearization is guaranteed not to make it worse at any point.
+ * a feerate not below GetChunk(0)'s, then moving IntersectPrefixes(subset) to the front of
+ * (what remains of) the linearization is guaranteed not to make it worse at any point.
*
* See https://delvingbitcoin.org/t/introduction-to-cluster-linearization/1032 for background.
diff --git a/src/test/fuzz/cluster_linearize.cpp b/src/test/fuzz/cluster_linearize.cpp
index 031cb04559..c97d00dea1 100644
--- a/src/test/fuzz/cluster_linearize.cpp
+++ b/src/test/fuzz/cluster_linearize.cpp
@@ -560,10 +560,10 @@ FUZZ_TARGET(clusterlin_linearization_chunking)
}
assert(combined == todo);
- // Verify the expected properties of LinearizationChunking::Intersect:
- auto intersect = chunking.Intersect(subset);
+ // Verify the expected properties of LinearizationChunking::IntersectPrefixes:
+ auto intersect = chunking.IntersectPrefixes(subset);
// - Intersecting again doesn't change the result.
- assert(chunking.Intersect(intersect) == intersect);
+ assert(chunking.IntersectPrefixes(intersect) == intersect);
// - The intersection is topological.
TestBitSet intersect_anc;
for (auto idx : intersect.transactions) {